==> nextcloud-28.0.14.tgz: nextcloud/apps/twofactor_totp/l10n/ug.js <==
OC.L10N.register(
    "twofactor_totp",
    {
    "You enabled TOTP two-factor authentication for your account" : "ھېساباتىڭىز ئۈچۈن TOTP ئىككى ئامىللىق دەلىللەشنى قوزغىتىڭ",
    "You disabled TOTP two-factor authentication for your account" : "ھېساباتىڭىز ئۈچۈن TOTP ئىككى ئامىللىق دەلىللەشنى چەكلىدىڭىز",
    "TOTP two-factor authentication disabled by an admin" : "باشقۇرغۇچى تەرىپىدىن TOTP ئىككى ئامىللىق دەلىللەش چەكلەنگەن",
    "TOTP (Authenticator app)" : "TOTP (دەلىللەش دېتالى)",
    "Authenticate with a TOTP app" : "TOTP دېتالى ئارقىلىق دەلىللەڭ",
    "Two-Factor TOTP Provider" : "ئىككى ئامىللىق TOTP تەمىنلىگۈچى",
    "TOTP two-factor provider" : "TOTP ئىككى ئامىل تەمىنلىگۈچى",
    "A Two-Factor-Auth Provider for TOTP (RFC 6238)" : "TOTP ئۈچۈن ئىككى ئامىللىق ئاپتور تەمىنلىگۈچى (RFC 6238)",
    "Enable TOTP" : "TOTP نى قوزغىتىڭ",
    "Could not enable TOTP" : "TOTP نى قوزغىتالمىدى",
    "Could not verify your key. Please try again" : "ئاچقۇچىڭىزنى دەلىللىيەلمىدى. قايتا سىناڭ",
    "Your new TOTP secret is:" : "يېڭى TOTP مەخپىيىتىڭىز:",
    "For quick setup, scan this QR code with your TOTP app:" : "تېز تەڭشەش ئۈچۈن ، بۇ QR كودىنى TOTP ئەپىڭىز بىلەن سايىلەڭ:",
    "After you configured your app, enter a test code below to ensure everything works correctly:" : "ئەپىڭىزنى تەڭشىگەندىن كېيىن ، تۆۋەندىكى سىناق كودىنى كىرگۈزۈپ ، ھەممە ئىشنىڭ نورمال ئىشلىشىگە كاپالەتلىك قىلىڭ:",
    "Authentication code" : "دەلىللەش كودى",
    "Verify" : "دەلىللەڭ",
    "Get the authentication code from the two-factor authentication app on your device." : "ئۈسكۈنىڭىزدىكى ئىككى ئامىللىق دەلىللەش دېتالىدىن دەلىللەش كودىغا ئېرىشىڭ.",
    "Submit" : "يوللاڭ"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-29.0.12.tgz: nextcloud/apps/twofactor_totp/l10n/ug.js <==
OC.L10N.register(
    "twofactor_totp",
    {
    "You enabled TOTP two-factor authentication for your account" : "ھېساباتىڭىز ئۈچۈن TOTP ئىككى ئامىللىق دەلىللەشنى قوزغىتىڭ",
    "You disabled TOTP two-factor authentication for your account" : "ھېساباتىڭىز ئۈچۈن TOTP ئىككى ئامىللىق دەلىللەشنى چەكلىدىڭىز",
    "TOTP (Authenticator app)" : "TOTP (دەلىللەش دېتالى)",
    "Authenticate with a TOTP app" : "TOTP دېتالى ئارقىلىق دەلىللەڭ",
    "Two-Factor TOTP Provider" : "ئىككى ئامىللىق TOTP تەمىنلىگۈچى",
    "Enable TOTP" : "TOTP نى قوزغىتىڭ",
    "Could not enable TOTP" : "TOTP نى قوزغىتالمىدى",
    "Could not verify your key. Please try again" : "ئاچقۇچىڭىزنى دەلىللىيەلمىدى. قايتا سىناڭ",
    "Your new TOTP secret is:" : "يېڭى TOTP مەخپىيىتىڭىز:",
    "For quick setup, scan this QR code with your TOTP app:" : "تېز تەڭشەش ئۈچۈن ، بۇ QR كودىنى TOTP ئەپىڭىز بىلەن سايىلەڭ:",
    "After you configured your app, enter a test code below to ensure everything works correctly:" : "ئەپىڭىزنى تەڭشىگەندىن كېيىن ، تۆۋەندىكى سىناق كودىنى كىرگۈزۈپ ، ھەممە ئىشنىڭ نورمال ئىشلىشىگە كاپالەتلىك قىلىڭ:",
    "Authentication code" : "دەلىللەش كودى",
    "Verify" : "دەلىللەڭ",
    "Get the authentication code from the two-factor authentication app on your device." : "ئۈسكۈنىڭىزدىكى ئىككى ئامىللىق دەلىللەش دېتالىدىن دەلىللەش كودىغا ئېرىشىڭ.",
    "Submit" : "يوللاڭ",
    "TOTP two-factor authentication disabled by an admin" : "باشقۇرغۇچى تەرىپىدىن TOTP ئىككى ئامىللىق دەلىللەش چەكلەنگەن",
    "TOTP two-factor provider" : "TOTP ئىككى ئامىل تەمىنلىگۈچى",
    "A Two-Factor-Auth Provider for TOTP (RFC 6238)" : "TOTP ئۈچۈن ئىككى ئامىللىق ئاپتور تەمىنلىگۈچى (RFC 6238)"
},
"nplurals=2; plural=(n != 1);");
